@@ -40,12 +40,19 @@ from concurrent import futures
 from typing import Dict, List, Tuple
 
 from engine.config import Config
-from engine.exceptions import (DatamapNotCSVException,
-                               NoApplicableSheetsInTemplateFiles,
-                               RemoveFileWithNoSheetRequiredByDatamap)
+from engine.exceptions import (
+    DatamapNotCSVException,
+    NoApplicableSheetsInTemplateFiles,
+    RemoveFileWithNoSheetRequiredByDatamap,
+)
 from engine.reports.validation import ValidationCheck, ValidationReportCSV
-from engine.utils.extraction import (ALL_IMPORT_DATA, check_datamap_sheets,
-                                     remove_failing_files, template_reader)
+from engine.utils.extraction import (
+    ALL_IMPORT_DATA,
+    check_datamap_sheets,
+    remove_failing_files,
+    template_reader,
+)
+from engine.utils.validation import validation_checker
 
 # pylint: disable=R0903,R0913;
 
@@ -62,94 +69,6 @@ logger = logging.getLogger(__name__)
 SKIP_MISSING_SHEETS = False
 
 
-def validation_checker(dm_data, tmp_data) -> Tuple[List[str], List["ValidationCheck"]]:
-    checks = []
-    wrong_types = []
-    files = tmp_data.keys()
-    for d in dm_data:
-        sheet = d["sheet"]
-        vtype = d["data_type"]
-        cellref = d["cellref"]
-        for f in files:
-            data = tmp_data[f]["data"]
-            sheets = data.keys()
-            for s in sheets:
-                if s == sheet:
-                    cellrefs = tmp_data[f]["data"][s].keys()
-                    if cellref not in cellrefs:
-                        # If the value is missing but datamap
-                        # declares it as untyped (missing vtype)
-                        # we must output "NA", otherwise the report
-                        # gets vtype
-                        if vtype == "":
-                            final_type = "NA"
-                        else:
-                            final_type = vtype
-                        checks.append(
-                            ValidationCheck(
-                                passes="FAIL",
-                                filename=f,
-                                key=d["key"],
-                                value="NO VALUE RETURNED",
-                                sheetname=s,
-                                cellref=cellref,
-                                wanted=final_type,
-                                got="EMPTY",
-                            )
-                        )
-                    for c in cellrefs:
-                        if c == cellref:
-                            if (
-                                vtype == ""
-                                or vtype not in Config.ACCEPTABLE_VALIDATION_TYPES
-                            ):
-                                if vtype != "":
-                                    wrong_types.append(vtype)
-                                    wanted_output = vtype
-                                else:
-                                    wanted_output = "NA"
-                                checks.append(
-                                    ValidationCheck(
-                                        passes="UNTYPED",
-                                        filename=f,
-                                        key=d["key"],
-                                        value=tmp_data[f]["data"][s][c]["value"],
-                                        sheetname=s,
-                                        cellref=c,
-                                        wanted=wanted_output,
-                                        got=tmp_data[f]["data"][s][c]["data_type"],
-                                    )
-                                )
-                                continue
-                            if tmp_data[f]["data"][s][c]["data_type"] == vtype:
-                                checks.append(
-                                    ValidationCheck(
-                                        passes="PASS",
-                                        filename=f,
-                                        key=d["key"],
-                                        value=tmp_data[f]["data"][s][c]["value"],
-                                        sheetname=s,
-                                        cellref=c,
-                                        wanted=vtype,
-                                        got=tmp_data[f]["data"][s][c]["data_type"],
-                                    )
-                                )
-                            else:
-                                checks.append(
-                                    ValidationCheck(
-                                        passes="FAIL",
-                                        filename=f,
-                                        key=d["key"],
-                                        value=tmp_data[f]["data"][s][c]["value"],
-                                        sheetname=s,
-                                        cellref=c,
-                                        wanted=vtype,
-                                        got=tmp_data[f]["data"][s][c]["data_type"],
-                                    )
-                                )
-    return (wrong_types, checks)
-
-
 class ParsePopulatedTemplatesUseCase:
     def __init__(self, repo):
         self.repo = repo
@@ -232,16 +151,10 @@ class ApplyDatamapToExtractionUseCaseWithValidation:
         self._datamap_data_dict = json.loads(self._datamap_data_json)
         self._template_data_dict = json.loads(self._template_data_json)
 
-        bad_types, self.validation_checks = validation_checker(
+        self.validation_checks = validation_checker(
             self._datamap_data_dict, self._template_data_dict
         )
 
-        if len(bad_types) > 0:
-            for t in set(bad_types):
-                logger.warning(
-                    f"{t} is not a valid type. Flagged as UNTYPED. Check your datamap."
-                )
-
         checks = check_datamap_sheets(self._datamap_data_dict, self._template_data_dict)
         # TODO -reintroduce SKIP_MISSING_SHEETS check here
         # We set a config variable to choose whether we
