@@ -5,11 +5,66 @@ from pathlib import Path
 from typing import Generator, List
 
 import pytest
+
 from engine.config import Config
 from engine.domain.datamap import DatamapLine, DatamapLineValueType
 from engine.domain.template import TemplateCell
 
 
+@pytest.fixture
+def sheet_data():
+    return {
+        "B2": {
+            "cellref": "B2",
+            "data_type": "TEXT",
+            "file_name": "/tmp/Documents/datamaps/input/test_template.xlsx",
+            "sheet_name": "Summary",
+            "value": "Text Key Value",
+        },
+        "B3": {
+            "cellref": "B3",
+            "data_type": "TEXT",
+            "file_name": "/tmp/Documents/datamaps/input/test_template.xlsx",
+            "sheet_name": "Summary",
+            "value": "String Key Value",
+        },
+        "F17": {
+            "cellref": "F17",
+            "data_type": "NUMBER",
+            "file_name": "/tmp/Documents/datamaps/input/test_template.xlsx",
+            "sheet_name": "Summary",
+            "value": "Big Float Value",
+        },
+    }
+
+
+@pytest.fixture
+def dm_data():
+    return [
+        {
+            "cellref": "B2",
+            "data_type": "TEXT",
+            "filename": "/home/lemon/code/python/bcompiler-engine/tests/resources/datamap_match_test_template.csv",
+            "key": "Text Key",
+            "sheet": "Summary",
+        },
+        {
+            "cellref": "B3",
+            "data_type": "TEXT",
+            "filename": "/home/lemon/code/python/bcompiler-engine/tests/resources/datamap_match_test_template.csv",
+            "key": "String Key",
+            "sheet": "Summary",
+        },
+        {
+            "cellref": "F17",
+            "data_type": "NUMBER",
+            "filename": "/home/lemon/code/python/bcompiler-engine/tests/resources/datamap_match_test_template.csv",
+            "key": "Big Float",
+            "sheet": "Summary",
+        },
+    ]
+
+
 @pytest.fixture
 def template_cell_obj() -> TemplateCell:
     return TemplateCell(
